@@ -13,7 +13,7 @@ test_that("plotbetas produces a graph", {
   test    <- plotbetas(dataset = testdata[[1]]$Dataset)
   
   # Test that a ggplot object is produced
-  expect_true(attr(test, "class")[1] == "gg")
+  expect_true(inherits(test, "gg"))
  
   testdata[[1]]$Dataset$ModelBetaQ <- testdata[[1]]$Dataset$ModelBeta
   testdata[[1]]$Dataset$Function   <- "quad"
@@ -34,4 +34,4 @@ test_that("plotbetas produces a graph", {
   # Test that a third graph is produced when func = cub
   expect_true(exists("beta3", envir = testenv))
   
-})
\ No newline at end of file
+})
